"use strict";
var __decorate = (this && this.__decorate) || function (decorators, target, key, desc) {
    var c = arguments.length, r = c < 3 ? target : desc === null ? desc = Object.getOwnPropertyDescriptor(target, key) : desc, d;
    if (typeof Reflect === "object" && typeof Reflect.decorate === "function") r = Reflect.decorate(decorators, target, key, desc);
    else for (var i = decorators.length - 1; i >= 0; i--) if (d = decorators[i]) r = (c < 3 ? d(r) : c > 3 ? d(target, key, r) : d(target, key)) || r;
    return c > 3 && r && Object.defineProperty(target, key, r), r;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.MagazineService = void 0;
const common_1 = require("@nestjs/common");
const default_service_1 = require("../../../common/service/default.service");
const magazine_entity_1 = require("./entity/magazine.entity");
const gsUtil_1 = require("../../../common/util/gsUtil");
const enum_1 = require("../../../common/enum/enum");
let MagazineService = class MagazineService extends default_service_1.DefaultService {
    async create(dto) {
        if (dto.displayType === enum_1.DISPLAY_TYPE.PERIOD) {
            dto.startDt = dto.startDt + ' 00:00:00';
            dto.endDt = dto.endDt + ' 23:59:59';
        }
        else {
            dto.startDt = null;
            dto.endDt = null;
        }
        return super.createBase(magazine_entity_1.Magazine, dto);
    }
    async findForAdmin(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager
            .createQueryBuilder(magazine_entity_1.Magazine, 'magazine')
            .leftJoinAndSelect('gs_manager', 'manager', 'magazine.managerSno = manager.sno')
            .leftJoinAndSelect((subQuery) => {
            return subQuery
                .select('gc.partnerSno', 'partnerSno')
                .addSelect('gc.contentSno', 'contentSno')
                .addSelect('COUNT(*)', 'commentCnt')
                .from('gs_comment', 'gc')
                .groupBy('gc.partnerSno, gc.contentSno');
        }, 'commentCounts', 'commentCounts.partnerSno = magazine.partnerSno AND commentCounts.contentSno = magazine.sno')
            .addSelect('commentCounts.commentCnt', 'commentCnt')
            .select([
            'magazine.*',
            'manager.id as id',
            'IFNULL(commentCnt,0) as commentCnt',
        ]);
        if (dto.category) {
            qb.andWhere('magazine.category LIKE :category', {
                category: `%${dto.category}%`,
            });
        }
        if (dto.partnerSno) {
            qb.andWhere('magazine.partnerSno = :partnerSno', {
                partnerSno: dto.partnerSno,
            });
        }
        if (dto.displayFl != null) {
            qb.andWhere('magazine.displayFl = :displayFl', {
                displayFl: dto.displayFl,
            });
        }
        if (dto.tag) {
            qb.andWhere('magazine.tag LIKE :tag', {
                tag: `%${dto.tag}%`,
            });
        }
        if (dto.title) {
            qb.andWhere('magazine.title LIKE :title', {
                title: `%${dto.title}%`,
            });
        }
        qb.offset(dto.skip);
        qb.limit(dto.take);
        qb.orderBy('magazine.sno', dto.order);
        const list = await qb.getRawMany();
        const count = await qb.getCount();
        const data = [list, count];
        return (0, gsUtil_1.paginateResponse)(data, dto.page, dto.take);
    }
    async find(dto) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(magazine_entity_1.Magazine, 'magazine');
        if (dto.category) {
            qb.andWhere('category LIKE :category', {
                category: `%${dto.category}%`,
            });
        }
        if (dto.partnerSno) {
            qb.andWhere('partnerSno = :partnerSno', {
                partnerSno: dto.partnerSno,
            });
        }
        qb.andWhere('displayFl = :displayFl', {
            displayFl: true,
        });
        if (dto.tag) {
            qb.andWhere('tag LIKE :tag', {
                tag: `%${dto.tag}%`,
            });
        }
        if (dto.title) {
            qb.andWhere('title LIKE :title', {
                title: `%${dto.title}%`,
            });
        }
        qb.andWhere(`(displayType = 'ALWAYS' OR CURDATE() BETWEEN startDt AND endDt)`);
        qb.offset(dto.skip);
        qb.limit(dto.take);
        qb.orderBy('sno', dto.order);
        const list = await qb.getRawMany();
        const count = await qb.getCount();
        const data = [list, count];
        return (0, gsUtil_1.paginateResponse)(data, dto.page, dto.take);
    }
    async findOneForAdmin(sno, partnerSno) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager
            .createQueryBuilder(magazine_entity_1.Magazine, 'magazine')
            .leftJoinAndSelect('gs_manager', 'manager', 'magazine.managerSno = manager.sno')
            .select(['magazine.*', 'manager.id as id']);
        if (partnerSno)
            qb.andWhere('magazine.partnerSno = :partnerSno', {
                partnerSno: partnerSno,
            });
        qb.andWhere('magazine.sno = :sno', { sno });
        const magazine = await qb.getRawOne();
        if (!magazine)
            throw new common_1.HttpException('조회 된 매거진이 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        return magazine;
    }
    async findOne(partnerSno, sno) {
        const entityManager = await this.getEntityManager();
        const qb = entityManager.createQueryBuilder(magazine_entity_1.Magazine, 'magazine');
        qb.andWhere(`(displayType = 'ALWAYS' OR CURDATE() BETWEEN startDt AND endDt)`);
        qb.andWhere('partnerSno = :partnerSno', {
            partnerSno: partnerSno,
        }).andWhere('sno = :sno', { sno: sno });
        const magazine = await qb.getOne();
        if (!magazine)
            throw new common_1.HttpException('조회 된 매거진이 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        return magazine;
    }
    async update(dto) {
        const magazine = await this.findOneForAdmin(dto.sno, dto.partnerSno);
        if (!magazine)
            throw new common_1.HttpException('조회 된 매거진이 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        if (magazine.managerSno != dto.managerSno)
            throw new common_1.HttpException('수정권한이 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        if (dto.displayType === enum_1.DISPLAY_TYPE.PERIOD) {
            if (dto.startDt == null || dto.endDt == null)
                throw new common_1.HttpException('시작일 또는 종료일을 입력하세요', common_1.HttpStatus.BAD_REQUEST);
        }
        if (dto.displayType === enum_1.DISPLAY_TYPE.PERIOD) {
            dto.startDt = dto.startDt + ' 00:00:00';
            dto.endDt = dto.endDt + ' 23:59:59';
        }
        else {
            dto.startDt = null;
            dto.endDt = null;
        }
        const entityManager = await this.getEntityManager();
        return await entityManager.update(magazine_entity_1.Magazine, { sno: dto.sno }, dto);
    }
    async deleteMagazine(partnerSno, managerSno, sno) {
        const magazine = await this.findOneForAdmin(sno, partnerSno);
        if (!magazine)
            throw new common_1.HttpException('조회 된 매거진이 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        if (magazine.managerSno != managerSno)
            throw new common_1.HttpException('삭제 권한이 없습니다.', common_1.HttpStatus.BAD_REQUEST);
        return super.delete(magazine_entity_1.Magazine, sno);
    }
};
exports.MagazineService = MagazineService;
exports.MagazineService = MagazineService = __decorate([
    (0, common_1.Injectable)()
], MagazineService);
//# sourceMappingURL=magazine.service.js.map